controls Package — Camelot documentation

### Navigation

- index
- modules |
- Camelot documentation »

# controls Package

## `controls` Package

## `abstract_widget` Module

class `camelot.view.controls.abstract_widget.` `AbstractSearchWidget`

  Bases: `PyQt4.QtGui.QWidget`

  `cancel_signal`
  `expand_search_options_signal`
  `on_arrow_down_signal`
  `search_signal`

## `action_widget` Module

Created on May 22, 2010

@author: tw55413

class `camelot.view.controls.action_widget.` `AbstractActionWidget`(action, gui_context)

  Bases: `object`

  `current_row_changed`(current_row)
  `data_changed`(index1, index2)
  `run_action`(mode=None)
  `set_state`(state)

class `camelot.view.controls.action_widget.` `ActionLabel`(action, gui_context, parent)

  Bases: `PyQt4.QtGui.QLabel`, `camelot.view.controls.action_widget.AbstractActionWidget`

  `enterEvent`(event)
  `entered`
  `leaveEvent`(event)
  `left`

    A custom interactive desktop button for the desktop. Each ‘button’ is actually an animated label.

  `onContainerMousePressEvent`(event)
  `resetLayout`()
  `setInteractive`(interactive)
  `set_state`(state)
  `startHoverAnimation`()
  `startNotificationAnimation`()
  `startSelectionAnimation`()
  `stopHoverAnimation`()
  `stopNotificationAnimation`()
  `updateSelectionAnimationState`(newState, oldState)

class `camelot.view.controls.action_widget.` `ActionPushButton`(action, gui_context, parent)

  Bases: `PyQt4.QtGui.QPushButton`, `camelot.view.controls.action_widget.AbstractActionWidget`

  `data_changed`(index1, index2)
  `set_state`(state)
  `triggered`()

## `actionsbox` Module

Actions box

class `camelot.view.controls.actionsbox.` `ActionsBox`(gui_context, parent)

  Bases: `PyQt4.QtGui.QWidget`

  A box containing actions to be applied to a view

  Parameters: | gui_context – a `camelot.admin.action.base.GuiContext` object parent – a `PyQt4.QtGui.QWidget` object

  `set_actions`(actions)

## `appscheme` Module

Encapsulates various ms office schemes

class `camelot.view.controls.appscheme.` `Scheme`(styledict={'ButtonSelectedMiddleBegin': '(255, 187, 110)', 'ButtonNormalEnd': '(192, 219, 255)', 'ButtonSelectedOverMiddleEnd': '(251, 140, 60)', 'ButtonNormalBegin': '(227, 239, 255)', 'CaptionDescBegin': '(227, 239, 255)', 'ButtonSelectedMiddleEnd': '(255, 171, 63)', 'ButtonMouseOverMiddleBegin': '(255, 232, 167)', 'CaptionBegin': '(227, 239, 255)', 'ButtonNormalMiddleBegin': '(196, 221, 255)', 'SplitterDark': '(192, 219, 255)', 'SplitterLight': '(227, 239, 255)', 'ContextMenuBackColor': '(227, 239, 255)', 'BorderColor': '(101, 147, 207)', 'CaptionTextColor': '(21, 66, 139)', 'ButtonMouseOverBegin': '(255, 254, 228)', 'SelectedTextColor': '(0, 0, 0)', 'ButtonMouseOverMiddleEnd': '(255, 215, 103)', 'ButtonMouseOverEnd': '(255, 230, 158)', 'ButtonSelectedOverMiddleBegin': '(255, 172, 66)', 'TextColor': '(32, 77, 137)', 'CaptionEnd': '(173, 209, 255)', 'ButtonSelectedBegin': '(255, 217, 170)', 'ButtonSelectedOverEnd': '(254, 211, 100)', 'ButtonSelectedEnd': '(254, 225, 122)', 'ButtonNormalMiddleEnd': '(173, 209, 255)', 'CaptionDescEnd': '(192, 219, 255)', 'ButtonSelectedOverBegin': '(255, 189, 105)'})

  Bases: `object`

  `bordercolor`()
  `captionbackground`()
  `captiontextcolor`()
  `color`(r, g, b)
  `fourcolorgradient`(rgb1, rgb2, rgb3, rgb4)
  `hoveredbackground`()
  `normalbackground`()
  `selectedbackground`(inverted=False)
  `selectedcolor`()
  `textcolor`()
  `twocolorgradient`(rgb1, rgb2)

## `busy_widget` Module

class `camelot.view.controls.busy_widget.` `BusyWidget`(parent=None)

  Bases: `PyQt4.QtGui.QWidget`

  A widget indicating the application is performing some background task. The widget acts as an overlay of its parent widget and displays animating orbs

  `paintEvent`(event)

    custom paint, painting the orbs

  `set_busy`(busy_state)

    start/stop the animation :arg busy_state: True or False

  `timerEvent`(event)

    custom timer event, updating the animation

## `calculator` Module

class `camelot.view.controls.calculator.` `Calculator`(parent=None)

  Bases: `PyQt4.QtGui.QDialog`

  `Calculate`()
  `SaveValue`()
  `ShowCalculate`()
  `buttonClick`(event)
  `calculation_finished_signal`
  `clearInput`()
  `discountClick`()
  `keyPressEvent`(event)
  `setValue`(value)

## `combobox_input_dialog` Module

class `camelot.view.controls.combobox_input_dialog.` `ComboBoxInputDialog`(autoaccept=False, parent=None)

  Bases: `PyQt4.QtGui.QDialog`

  `count`()
  `get_text`()
  `set_cancel_button_default`()
  `set_cancel_button_text`(text)
  `set_choice_by_index`(index)
  `set_choice_by_text`(text)
  `set_data`(index, data, role)
  `set_items`(items)
  `set_label_text`(text)
  `set_ok_button_default`()
  `set_ok_button_text`(text)
  `set_window_title`(title)

## `dashboard` Module

class `camelot.view.controls.dashboard.` `BareFrame`(parent=None)

  Bases: `PyQt4.QtGui.QFrame`

  `setBGColor`(color)

class `camelot.view.controls.dashboard.` `CloseMark`(pixmap, parent=None)

  Bases: `PyQt4.QtGui.QLabel`

  `HEIGHT` = 31
  `MARGIN` = 10
  `WIDTH` = 31
  `mousePressEvent`(event)
  `toParentTopRight`()

class `camelot.view.controls.dashboard.` `Dashboard`(parent=None)

  Bases: `camelot.view.controls.dashboard.BareFrame`

  `SCALE` = 0.85

## `decorated_line_edit` Module

class `camelot.view.controls.decorated_line_edit.` `DecoratedLineEdit`(parent=None)

  Bases: `PyQt4.QtGui.QLineEdit`

  A QLineEdit with additional decorations :

  > - a background text, visible when the line edit doesn’t contain any text
  > - a validity, which will trigger the background color

  Use the user_input method to get the text that was entered by the user.

  Note : since QT 4.7 the background text could be replaced with the setPlaceholderText on a QLineEdit

  `arrow_down_key_pressed`
  `focusInEvent`(e)
  `focusOutEvent`(e)
  `keyPressEvent`(e)
  `paintEvent`(event)
  `set_background_text`(background_text)

    Set the text to be displayed in the background when the line input does not contain any text :param background_text: the text to be shown, None if no text should be shown

  `set_minimum_width`(width)

    Set the minimum width of the line edit, measured in number of characters. :param width: the number of characters that should be visible in the

    > editor

  `set_user_input`(text)
  `set_valid`(valid)

    Set the validity of the current content of the line edit :param valid: True or False

  `user_input`()

## `exception` Module

Functions and widget to represent exceptions to the user

class `camelot.view.controls.exception.` `ExceptionDialog`(exception_info)

  Bases: `PyQt4.QtGui.QMessageBox`

  Dialog to display an exception to the user

`camelot.view.controls.exception.` `model_thread_exception_message_box`(exception_info)

  Display an exception that occurred in the model thread in a message box, use this function as the exception argument in the model thread’s post function to represent the exception to the user

  Parameters: | exception_info – a tuple containing exception information

`camelot.view.controls.exception.` `register_exception`(logger, text, exception)

  Log an exception and return a serialized form of the exception with exception information in a user readable format, to be used when displaying an exception message box.

  that serialized form can be fed to the model_thread_exception_message_box function.

  Returns: | a tuple with exception information

## `field_label` Module

class `camelot.view.controls.field_label.` `Attribute`(name, value)

  Bases: `object`

  Helper class representing a field attribute’s name and its value

  class `Admin`(app_admin, entity)

    Bases: `camelot.admin.object_admin.ObjectAdmin`

    `field_attributes` = {'name': {'minimal_column_width': 25}, 'value': {'minimal_column_width': 25}}
    `list_display` = ['name', 'value']

class `camelot.view.controls.field_label.` `FieldLabel`(field_name, text, field_attributes, admin, parent=None)

  Bases: `camelot.view.controls.user_translatable_label.UserTranslatableLabel`

  A Label widget used to display the name of a field on a form. This label provides the user with the possibility to change the translation of the label and review its field attributes.

  `font_width` = None
  `get_attributes`()
  `show_field_attributes`()
  `sizeHint`()

## `filter_operator` Module

class `camelot.view.controls.filter_operator.` `FilterOperator`(entity, field_name, field_attributes, parent)

  Bases: `PyQt4.QtGui.QWidget`

  Widget that allows applying various filter operators on a field

  `combobox_changed`(index)

    Whenever the combobox changes, show or hide the appropriate editors and emit the filter_changed signal

  `decorate_query`(query)

    Parameters: | query – an sqlalchemy query
    Returns: | the input query transformed to take into account the filter of

    this widget

  `editor_editing_finished`()

    Whenever one of the editors their value changes, emit the filters changed signal

  `filter_changed_signal`
  `get_operator_and_arity`()

    Returns: | the current operator and its arity

## `filterlist` Module

Controls to filter data

class `camelot.view.controls.filterlist.` `FilterList`(items, parent)

  Bases: `PyQt4.QtGui.QWidget`

  A list with filters that can be applied on a query in the tableview

  `decorate_query`(query)
  `emit_filters_changed`()
  `filters_changed_signal`

## `formview` Module

form view

class `camelot.view.controls.formview.` `ContextMenuAction`(parent, title, icon=None)

  Bases: `PyQt4.QtGui.QAction`

  `default_icon` = Icon('tango/16x16/categories/applications-system.png')

class `camelot.view.controls.formview.` `FormEditors`(columns, widget_mapper, delegate, admin)

  Bases: `object`

  A class that holds the editors used on a form

  `bold_font` = None
  `create_editor`(field_name, parent)

    Returns: | a `QtGuiQWidget` or None if field_name is unknown

  `create_label`(field_name, editor, parent)
  `option` = None

class `camelot.view.controls.formview.` `FormView`(title, admin, model, index)

  Bases: `camelot.view.controls.view.AbstractView`

  A FormView is the combination of a FormWidget, possible actions and menu items

  view

  `closeEvent`(event)
  `form_widget`

    alias of `FormWidget`

  `refresh`()

    Refresh the data in the current view

  `refresh_session`()
  `setActions`(actions)
  `showMessage`(valid)
  `toHtml`(*args, **kwargs)

    generates html of the form

  `update_title`(current_index)
  `validateClose`()
  `viewFirst`()

    select model’s first row

  `viewLast`()

    select model’s last row

  `viewNext`()

    select model’s next row

  `viewPrevious`()

    select model’s previous row

class `camelot.view.controls.formview.` `FormWidget`(parent, admin)

  Bases: `PyQt4.QtGui.QWidget`

  A form widget comes inside a form view or inside an embedded manytoone editor

  `changed_signal`
  `clear_mapping`()
  `export_ooxml`()
  `get_index`()
  `get_model`()
  `set_index`(index)
  `set_model`(model)
  `submit`()
  `to_first`()
  `to_last`()
  `to_next`()
  `to_previous`()

## `inheritance` Module

Controls related to visualizing object hierarchy

class `camelot.view.controls.inheritance.` `SubclassDialog`(parent, admin)

  Bases: `PyQt4.QtGui.QDialog`

  A dialog requesting the user to select a subclass

class `camelot.view.controls.inheritance.` `SubclassItem`(parent, admin)

  Bases: `camelot.view.controls.modeltree.ModelItem`

class `camelot.view.controls.inheritance.` `SubclassTree`(admin, parent)

  Bases: `camelot.view.controls.modeltree.ModelTree`

  Widget to select subclasses of a certain entity, where the subclasses are represented in a tree

  emits subclassClicked when a subclass has been selected

  `emit_subclass_clicked`(index)
  `setSubclasses`(subclasses)
  `subclass_clicked_signal`

## `liteboxview` Module

class `camelot.view.controls.liteboxview.` `CloseMark`(pixmap=None, hover_pixmap=None, parent=None)

  Bases: `PyQt4.QtGui.QGraphicsPixmapItem`

  `hoverEnterEvent`(event)
  `hoverLeaveEvent`(event)
  `mousePressEvent`(event)

class `camelot.view.controls.liteboxview.` `LiteBoxView`(parent=None)

  Bases: `PyQt4.QtGui.QGraphicsView`

  `ALPHA` = <PyQt4.QtGui.QColor object at 0x9f639cc>
  `close`()
  `closed_signal`
  `drawBackground`(painter, rect)
  `show_fullscreen_image`(image)

    Parameters: | image – a QImage

  `show_fullscreen_item`(item)

    Parameters: | item – a QGraphicsItem to be shown fullscreen

  `show_fullscreen_pixmap`(pixmap)

    Parameters: | pixmap – a QPixmap

  `show_fullscreen_svg`(path)

    Parameters: | path – path to an svg file

`camelot.view.controls.liteboxview.` `fit_to_screen`(pixmap)

`camelot.view.controls.liteboxview.` `get_desktop`()

`camelot.view.controls.liteboxview.` `get_desktop_pixmap`()

## `modeltree` Module

custom tree and tree-items widgets

class `camelot.view.controls.modeltree.` `ModelItem`(parent, columns_names, section_item)

  Bases: `PyQt4.QtGui.QTreeWidgetItem`

  Custom tree item widget

  `set_icon`(icon)

class `camelot.view.controls.modeltree.` `ModelTree`(header_labels=[''], parent=None)

  Bases: `PyQt4.QtGui.QTreeWidget`

  Custom tree widget

  `clear_model_items`()
  `clear_section_items`()
  `fix_header_labels`()
  `leaveEvent`(event)
  `mouseMoveEvent`(event)
  `mousePressEvent`(event)

    Custom context menu

  `resizeEvent`(event)

## `navpane2` Module

left navigation pane

class `camelot.view.controls.navpane2.` `NavigationPane`(app_admin, workspace, parent)

  Bases: `PyQt4.QtGui.QDockWidget`

  `get_sections`()
  `set_sections`(sections)
  `update_sections`()
  `wheelEvent`(wheel_event)

class `camelot.view.controls.navpane2.` `PaneSection`(parent, section, workspace)

  Bases: `PyQt4.QtGui.QWidget`

  `create_context_menu`(point)
  `set_items`(items)

## `progress_dialog` Module

Functions and classes to use a progress dialog in combination with a model thread

class `camelot.view.controls.progress_dialog.` `ProgressDialog`(name, icon=Icon('tango/32x32/actions/appointment-new.png'))

  Bases: `PyQt4.QtGui.QProgressDialog`

  A Progress Dialog to be used in combination with a post to the model thread:

  to display a progress dialog until my_function has finished:

      d = ProgressDialog()
      post(my_function, d.finished, d.exception)
      d.exec_()

  `display_chart`(chart)
  `display_pixmap`(pixmap)

    Parameters: | image – a camelot.view.art.Pixmap object

  `exception`(exception_info)
  `exit`(return_code)

    Stop the application event loop, with the given return code

  `finished`(success=True)
  `progress_icon` = Icon('tango/32x32/actions/appointment-new.png')

## `search` Module

class `camelot.view.controls.search.` `SimpleSearchControl`(parent)

  Bases: `camelot.view.controls.abstract_widget.AbstractSearchWidget`

  A control that displays a single text field in which search keywords can be typed

  emits a search and a cancel signal if the user starts or cancels the search

  `emit_cancel`()
  `emit_expand_search_options`()
  `emit_search`(str='')
  `on_arrow_down_key_pressed`()
  `search`(search_text)

    Start searching for search_text

## `standalone_wizard_page` Module

class `camelot.view.controls.standalone_wizard_page.` `HSeparator`(parent=None)

  Bases: `PyQt4.QtGui.QFrame`

class `camelot.view.controls.standalone_wizard_page.` `StandaloneWizardPage`(window_title=None, parent=None, flags=<PyQt4.QtCore.WindowFlags object at 0x9e62ae4>)

  Bases: `PyQt4.QtGui.QDialog`

  A Standalone Wizard Page Dialog for quick configuration windows

  `banner_layout`()
  `banner_logo_holder`()
  `banner_text_layout`()
  `banner_widget`()
  `buttons_widget`()
  `main_widget`()
  `set_banner_logo_pixmap`(pixmap)
  `set_banner_subtitle`(subtitle)
  `set_banner_title`(title)
  `set_layouts`(*args, **kwargs)

## `statusbar` Module

A custom status bar containing a progress indicator

class `camelot.view.controls.statusbar.` `StatusBar`(parent)

  Bases: `PyQt4.QtGui.QStatusBar`

## `tableview` Module

Tableview

class `camelot.view.controls.tableview.` `AdminTableWidget`(admin, parent=None)

  Bases: `camelot.view.controls.tableview.TableWidget`

  A table widget that inspects the admin class and changes the behavior of the table as specified in the admin class

  `copy_selected_rows`()
  `delete_selected_rows`()

class `camelot.view.controls.tableview.` `FrozenTableWidget`(parent, columns_frozen)

  Bases: `PyQt4.QtGui.QTableView`

  A table widget to be used as the frozen table widget inside a table widget.

  `currentChanged`(current, previous)

    When the current index has changed, prevent it to jump to a column that is not frozen

class `camelot.view.controls.tableview.` `HeaderWidget`(parent, admin)

  Bases: `PyQt4.QtGui.QWidget`

  HeaderWidget for a tableview, containing the title, the search widget, and the number of rows in the table

  `decorate_query`(query)

    Apply expanded filters on the query

  `expand_search_options`()
  `filters_changed_signal`
  `rows_widget`

    alias of `RowsWidget`

  `search_widget`

    alias of `SimpleSearchControl`

  `setNumberOfRows`(*args, **kwargs)

class `camelot.view.controls.tableview.` `RowsWidget`(parent)

  Bases: `PyQt4.QtGui.QLabel`

  Widget that is part of the header widget, displaying the number of rows in the table view

  `setNumberOfRows`(rows)

class `camelot.view.controls.tableview.` `Splitter`

  Bases: `PyQt4.QtGui.QSplitter`

  Custom implementation of QSplitter to use the custom SplitterHandle

  `createHandle`()

class `camelot.view.controls.tableview.` `SplitterHandle`(orientation, splitter, widget_to_hide=None)

  Bases: `PyQt4.QtGui.QSplitterHandle`

  Custom implementation of QSplitterHandle to provide more functions, such as hiding a widget by clicking the handle

  `mousePressEvent`(event)

class `camelot.view.controls.tableview.` `TableView`(admin, search_text=None, parent=None)

  Bases: `camelot.view.controls.view.AbstractView`

  A generic tableview widget that puts together some other widgets. The behaviour of this class and the resulting interface can be tuned by specifying specific class attributes which define the underlying widgets used

      class MovieRentalTableView(TableView):
        title_format = 'Grand overview of recent movie rentals'

  The attributes that can be specified are :

  `header_widget`

  The widget class to be used as a header in the table view:

      header_widget = HeaderWidget

  `table_widget`

  The widget class used to display a table within the table view

  table_widget = TableWidget

  `title_format`

  A string used to format the title of the view

  title_format = ‘%(verbose_name_plural)s’

  `table_model`

  A class implementing QAbstractTableModel that will be used as a model for the table view

      table_model = QueryTableProxy

  - emits the row_selected signal when a row has been selected
  class `AdminTableWidget`(admin, parent=None)

    Bases: `camelot.view.controls.tableview.TableWidget`

    A table widget that inspects the admin class and changes the behavior of the table as specified in the admin class

    `copy_selected_rows`()
    `delete_selected_rows`()
  `TableView.` `activate_search`()
  `TableView.` `cancelSearch`()

    resets search filtering to default

  `TableView.` `closeEvent`(event)

    reimplements close event

  `TableView.` `copy_selected_rows`()

    Copy the selected rows in this tableview

  `TableView.` `create_table_model`(admin)

    Create a table model for the given admin interface

  `TableView.` `deleteSelectedRows`()

    delete the selected rows in this tableview

  `TableView.` `focusTable`()
  `TableView.` `getColumns`()

    return the columns to be displayed in the table view

  `TableView.` `getData`()

    generator for data queried by table model

  `TableView.` `getTitle`()

    return the name of the entity managed by the admin attribute

  `TableView.` `get_admin`()
  `TableView.` `get_collection_getter`(*args, **kwargs)

    Returns: | a list with all the objects corresponding to the rows in the table

  `TableView.` `get_model`()
  `TableView.` `get_selection_getter`(*args, **kwargs)

    Returns: | a function that when called return an iterable with all the

    objects corresponding to the selected rows in the table.

  `TableView.` `get_title`(*args, **kwargs)
  `TableView.` `header_widget`

    alias of `HeaderWidget`

  `TableView.` `importFromFile`()

    “import data : the data will be imported in the activeMdiChild

  `TableView.` `makeImport`()
  `TableView.` `newRow`(*args, **kwargs)

    Create a new row in the tableview

  `TableView.` `on_keyboard_selection_signal`()
  `TableView.` `rebuild_query`()

    resets the table model query

  `TableView.` `refresh`()

    Refresh the whole view

  `TableView.` `row_selected_signal`
  `TableView.` `sectionClicked`(section)

    emits a row_selected signal

  `TableView.` `selectTableRow`(row)

    selects the specified row

  `TableView.` `select_all_rows`()
  `TableView.` `selectedTableIndexes`(*args, **kwargs)

    returns a list of selected rows indexes

  `TableView.` `setSubclassTree`(*args, **kwargs)
  `TableView.` `set_admin`(*args, **kwargs)

    Switch to a different subclass, where admin is the admin object of the subclass

  `TableView.` `set_filters_and_actions`(*args, **kwargs)

    sets filters for the tableview

  `TableView.` `startSearch`(text)

    rebuilds query based on filtering text

  `TableView.` `tableLayoutChanged`(*args, **kwargs)
  `TableView.` `table_model`

    alias of `QueryTableProxy`

  `TableView.` `title_format` = '%(verbose_name_plural)s'
  `TableView.` `to_html`()

    generates html of the table

  `TableView.` `viewFirst`()

    selects first row

  `TableView.` `viewLast`()

    selects last row

  `TableView.` `viewNext`()

    selects next row

  `TableView.` `viewPrevious`()

    selects previous row

class `camelot.view.controls.tableview.` `TableWidget`(parent=None, columns_frozen=0, lines_per_row=1)

  Bases: `PyQt4.QtGui.QTableView`

  A widget displaying a table, to be used within a TableView. This is a pumped up version of the QTableView widget providing extra functions such as frozen columns. But it does not rely on the model being Camelot specific, or a Collection Proxy.

  `margin`

  margin, specified as a number of pixels, used to calculate the height of a row in the table, the minimum row height will allow for this number of pixels below and above the text.

  `activated`(selectedIndex, previousSelectedIndex)
  `close_editor`()

    Close the active editor, this method is used to prevent assertion failures in QT when an editor is still open in the view for a cell that no longer exists in the model

    those assertion failures only exist in QT debug builds.

  `edit`(index, trigger=None, event=None)
  `horizontal_section_clicked`(logical_index)

    Update the sorting of the model and the header

  `keyPressEvent`(e)
  `keyboard_selection_signal`
  `margin` = 5
  `moveCursor`(cursorAction, modifiers)
  `resizeEvent`(event)
  `scrollTo`(index, hint)
  `setItemDelegate`(item_delegate)
  `setModel`(model)

## `user_translatable_label` Module

class `camelot.view.controls.user_translatable_label.` `TranslateLabelAction`(parent)

  Bases: `PyQt4.QtGui.QAction`

  `translate_icon` = Icon('tango/16x16/apps/preferences-desktop-locale.png')

class `camelot.view.controls.user_translatable_label.` `UserTranslatableLabel`(text, parent=None)

  Bases: `PyQt4.QtGui.QLabel`

  A QLabel that allows the user to translate the text contained within by right clicking on it and selecting the appropriate submenu.

  `change_translation`()
  `create_update_translation_table`(source, language, value)

## `view` Module

Functionality common to TableViews and FormViews

class `camelot.view.controls.view.` `AbstractView`

  Bases: `PyQt4.QtGui.QWidget`

  A string used to format the title of the view :: title_format = ‘Movie rental overview’

  `header_widget`

  The widget class to be used as a header in the table view:

  header_widget = None

  `change_icon`(new_icon)
  `change_title`(new_title)

    Will emit the title_changed_signal

  `export_to_excel`(*args, **kwargs)
  `export_to_mail`(*args, **kwargs)
  `export_to_word`(*args, **kwargs)
  `header_widget` = None
  `icon_changed_signal`
  `refresh`()

    Refresh the data in the current view

  `title_changed_signal`
  `title_format` = ''
  `to_html`(*args, **kwargs)

class `camelot.view.controls.view.` `TabView`(parent, views=[], admin=None)

  Bases: `camelot.view.controls.view.AbstractView`

  Class to combine multiple views in Tabs and let them behave as one view. This class can be used when defining custom create_table_view methods on an ObjectAdmin class to group multiple table views together in one view.

  `export_to_excel`()
  `export_to_mail`()
  `export_to_word`()
  `refresh`()

    Refresh the data in the current view

  `set_views_and_titles`(views_and_titles)
  `to_html`()

## Subpackages

- delegates Package
  - `delegates` Package
    - BoolDelegate
    - ChartDelegate
    - CodeDelegate
    - ColorDelegate
    - ColoredFloatDelegate
    - ComboBoxDelegate
    - CurrencyDelegate
    - DateDelegate
    - DateTimeDelegate
    - EnumerationDelegate
    - FileDelegate
    - FloatDelegate
    - ImageDelegate
    - IntegerDelegate
    - IntervalsDelegate
    - LabelDelegate
    - LanguageDelegate
    - LocalFileDelegate
    - Many2OneDelegate
    - ManyToManyDelegate
    - ManyToOneChoicesDelegate
    - MonthsDelegate
    - NoteDelegate
    - One2ManyDelegate
    - PlainTextDelegate
    - RichTextDelegate
    - SmileyDelegate
    - StarDelegate
    - TextBoolDelegate
    - TextEditDelegate
    - TimeDelegate
    - VirtualAddressDelegate
  - `booldelegate` Module
  - `chartdelegate` Module
  - `codedelegate` Module
  - `colordelegate` Module
  - `coloredfloatdelegate` Module
  - `comboboxdelegate` Module
  - `currencydelegate` Module
  - `customdelegate` Module
  - `datedelegate` Module
  - `datetimedelegate` Module
  - `delegatemanager` Module
  - `enumerationdelegate` Module
  - `filedelegate` Module
  - `floatdelegate` Module
  - `imagedelegate` Module
  - `integerdelegate` Module
  - `intervalsdelegate` Module
  - `labeldelegate` Module
  - `languagedelegate` Module
  - `localfiledelegate` Module
  - `many2onedelegate` Module
  - `manytomanydelegate` Module
  - `manytoonechoicesdelegate` Module
  - `monthsdelegate` Module
  - `notedelegate` Module
  - `one2manydelegate` Module
  - `plaintextdelegate` Module
  - `richtextdelegate` Module
  - `smileydelegate` Module
  - `stardelegate` Module
  - `texteditdelegate` Module
  - `timedelegate` Module
  - `virtualaddressdelegate` Module
- editors Package
  - `editors` Package
  - `abstractmanytooneeditor` Module
  - `booleditor` Module
  - `charteditor` Module
  - `choiceseditor` Module
  - `codeeditor` Module
  - `coloredfloateditor` Module
  - `coloreditor` Module
  - `customeditor` Module
  - `dateeditor` Module
  - `datetimeeditor` Module
  - `embeddedmany2oneeditor` Module
  - `fileeditor` Module
  - `floateditor` Module
  - `imageeditor` Module
  - `integereditor` Module
  - `labeleditor` Module
  - `languageeditor` Module
  - `localfileeditor` Module
  - `many2oneeditor` Module
  - `manytomanyeditor` Module
  - `monthseditor` Module
  - `noteeditor` Module
  - `one2manyeditor` Module
  - `onetomanychoiceseditor` Module
  - `richtexteditor` Module
  - `smileyeditor` Module
  - `stareditor` Module
  - `textediteditor` Module
  - `textlineeditor` Module
  - `timeeditor` Module
  - `virtualaddresseditor` Module
  - `wideeditor` Module

### Navigation

- index
- modules |
- Camelot documentation »

Comments
blog comments powered by Disqus